"""TurboGears project related information"""
version = "2.1.1"
description = "Next generation TurboGears built on Pylons"
long_description="""
TurboGears brings together a best of breed python tools
to create a flexible, full featured, and easy to use web
framework.

TurboGears 2 provides an integrated and well tested set of tools for
everything you need to build dynamic, database driven applications.
It provides a full range of tools for front end javascript
develeopment, back database development and everything in between:

 * dynamic javascript powered widgets (ToscaWidgets)
 * automatic JSON generation from your controllers
 * powerful, designer friendly XHTML based templating (Genshi)
 * object or route based URL dispatching
 * powerful Object Relational Mappers (SQLAlchemy)

The latest development version is available in the
`TurboGears Git repository`_.

.. _TurboGears Git repository:
    https://sourceforge.net/p/turbogears2/tg2/
"""
url="http://www.turbogears.org/"
author= "Mark Ramm, Christopher Perkins, Jonathan LaCour, Rick Copland, Alberto Valverde, and the TurboGears community"
email = "mark.ramm@gmail.com, alberto@toscat.net, m.pedersen@icelus.org"
copyright = """Copyright 2005-2011 Kevin Dangoor,
Alberto Valverde, Mark Ramm, Christopher Perkins and contributors"""
license = "MIT"
